@@ -7,9 +7,31 @@ Cite as: `Astrophysics Source Code Library, record ascl:1112.014
 
 This package can load and use a Jet Propulsion Laboratory (JPL)
 ephemeris for predicting the position and velocity of a planet or other
-Solar System body.  It only needs `NumPy <http://www.numpy.org/>`_,
-which ``pip`` will automatically attempt to install alongside
-``pyephem`` when you run::
+Solar System body.  It currently supports binary SPK files (extension
+``.bsp``) like `those distributed by the Jet Propulsion Laboratory
+<https://ssd.jpl.nasa.gov/ftp/eph/planets/bsp/>`_ that are:
+
+* **Type 2** — positions stored as Chebyshev polynomials, with velocity
+  derived by computing their derivative.
+
+* **Type 3** — positions and velocities both stored explicitly as
+  Chebyshev polynomials.
+
+* **Type 9** — a series of discrete positions and velocities, with
+  separate timestamps that do not need to be equally spaced.  Currently
+  there is only support for linear interpolation: for Type 9 ephemerides
+  of polynomial degree 1, not of any higher degrees.
+
+Note that even if an ephemeris isn’t one of the above types, you can
+still use ``jplephem`` to read its text comment and list the segments
+inside, using the subcommands ``comment`` and ``daf`` described below.
+
+Installation
+------------
+
+The only third-party package that ``jplephem`` depends on is `NumPy
+<http://www.numpy.org/>`_, which ``pip`` will automatically attempt to
+install alongside ``pyephem`` when you run::
 
     $ pip install jplephem
 
@@ -54,7 +76,7 @@ limiting the range of dates that it covers::
 You will get an error if your starting year is negative, because Unix
 commands expect a list of options when they see a dash.  The fix is to
 provide a special argument ``--`` which says “I’m done passing options,
-even if the next argument stars with a dash”:
+even if the next argument stars with a dash”::
 
     python -m jplephem excerpt -- -800/1/1 800/1/1 de422.bsp excerpt422.bsp
 
@@ -308,52 +330,6 @@ You can ask for velocity as well.
 >>> print(v)
 [6.707e-09 4.838e-10 2.655e-06]
 
-Legacy Ephemeris Packages
--------------------------
-
-Back before I learned about SPICE and SPK files, I had run across the
-text-file formatted JPL ephemerides at:
-
-ftp://ssd.jpl.nasa.gov/pub/eph/planets/ascii/
-
-I laboriously assembled the data in these text files into native NumPy
-array files and wrapped them each in a Python package so that users
-could install an ephemeris with a simple command::
-
-    pip install de421
-
-If you want to use one of these pip-installable ephemerides, you will be
-using a slightly older API, and will lose the benefit of the efficient
-memory-mapping that the newer SPK code performs.  With the old API, here
-is how you would load DE421 and compute a position, given a barycentric
-dynamical time expressed as a Julian date::
-
-    import de421
-    from jplephem import Ephemeris
-
-    eph = Ephemeris(de421)
-    x, y, z = eph.position('mars', 2444391.5)  # 1980.06.01
-
-For more information about the legacy API, consult the ``jplephem``
-entry on PyPI for the final release of the 1.x series:
-
-https://pypi.python.org/pypi/jplephem/1.2
-
-The ephemerides that were made available as Python packages (the
-following links explain the differences between them) are:
-
-* `DE405 <http://pypi.python.org/pypi/de405>`_ (May 1997)
-  — 54 MB covering years 1600 through 2200
-* `DE406 <http://pypi.python.org/pypi/de406>`_ (May 1997)
-  — 190 MB covering years -3000 through 3000
-* `DE421 <http://pypi.python.org/pypi/de421>`_ (February 2008)
-  — 27 MB covering years 1900 through 2050
-* `DE422 <http://pypi.python.org/pypi/de422>`_ (September 2009)
-  — 531 MB covering years -3000 through 3000
-* `DE423 <http://pypi.python.org/pypi/de423>`_ (February 2010)
-  — 36 MB covering years 1800 through 2200
-
-
 Reporting issues
 ----------------
 
@@ -361,10 +337,13 @@ You can report any issues, bugs, or problems at the GitHub repository:
 
 https://github.com/brandon-rhodes/python-jplephem/
 
-
 Changelog
 ---------
 
+**2021 December 31 — Version 2.17**
+
+* Fixed an ``AttributeError`` in the ``excerpt`` command.
+
 **2021 July 3 — Version 2.16**
 
 * Fixed a ``ValueError`` raised in the ``excerpt`` command when an
@@ -517,6 +496,6 @@ FTP site: ftp://ssd.jpl.nasa.gov/pub/eph/planets/fortran/
 
 """
 from .ephem import Ephemeris, DateError
-__version__ = '2.16'
+__version__ = '2.17'
 
 __all__ = ['Ephemeris', 'DateError', '__version__']
